@@ -136,8 +136,12 @@ class SortImports(object):
                                                                                    self.file_encoding,
                                                                                    file_to_import_sort.encoding))
         elif file_:
-            self.file_encoding = coding_check(file_)
-            file_.seek(0)
+            try:
+                file_.seek(0)
+                self.file_encoding = coding_check(file_)
+                file_.seek(0)
+            except io.UnsupportedOperation:
+                pass
             reader = codecs.getreader(self.file_encoding)
             file_contents = reader(file_).read()
 
@@ -219,8 +223,8 @@ class SortImports(object):
             check_output = self.output
             check_against = file_contents
             if self.config['ignore_whitespace']:
-                check_output = check_output.replace(self.line_separator, "").replace(" ", "")
-                check_against = check_against.replace(self.line_separator, "").replace(" ", "")
+                check_output = check_output.replace(self.line_separator, "").replace(" ", "").replace("\x0c", "")
+                check_against = check_against.replace(self.line_separator, "").replace(" ", "").replace("\x0c", "")
 
             if check_output.strip() == check_against.strip():
                 if self.config['verbose']:
@@ -232,6 +236,8 @@ class SortImports(object):
         if show_diff or self.config['show_diff']:
             self._show_diff(file_contents)
         elif write_to_stdout:
+            if sys.version_info[0] < 3:
+                self.output = self.output.encode(self.file_encoding)
             sys.stdout.write(self.output)
         elif file_name and not check:
             if self.output == file_contents:
@@ -825,7 +831,7 @@ class SortImports(object):
             self._in_top_comment = True
             return True
         elif self._in_top_comment:
-            if not line.startswith("#"):
+            if not line.startswith("#") or line in self._section_comments:
                 self._in_top_comment = False
                 self._first_comment_index_end = self.index - 1
 
